pub(crate) struct FetchMetadata {
command: MetadataCommand,
manifest_path: ManifestPath,
lockfile_copy: Option<LockfileCopy>,
kind: &'static str,
no_deps: bool,
no_deps_result: Result<Metadata>,
other_options: Vec<String>,
}Fields
command: MetadataCommandmanifest_path: ManifestPathlockfile_copy: Option<LockfileCopy>kind: &'static strno_deps: boolno_deps_result: Result<Metadata>other_options: Vec<String>Implementations
Sourceimpl FetchMetadata
impl FetchMetadata
Sourcepub(crate) fn new(
cargo_toml: &ManifestPath,
current_dir: &AbsPath,
config: &CargoMetadataConfig,
sysroot: &Sysroot,
no_deps: bool,
) -> Self
pub(crate) fn new( cargo_toml: &ManifestPath, current_dir: &AbsPath, config: &CargoMetadataConfig, sysroot: &Sysroot, no_deps: bool, ) -> Self
Builds a command to fetch metadata for the given cargo_toml manifest.
Performs a lightweight pre-fetch using the --no-deps option,
available via FetchMetadata::no_deps_metadata, to gather basic
information such as the target-dir.
The provided sysroot is used to set the RUSTUP_TOOLCHAIN
environment variable when invoking Cargo, ensuring that the
rustup proxy selects the correct toolchain.
Sourcepub(crate) fn exec(
self,
locked: bool,
progress: &dyn Fn(String),
) -> Result<(Metadata, Option<Error>)>
pub(crate) fn exec( self, locked: bool, progress: &dyn Fn(String), ) -> Result<(Metadata, Option<Error>)>
Executes the metadata-fetching command.
A successful result may still contain a metadata error if the full fetch failed,
but the fallback --no-deps pre-fetch succeeded during command construction.